import { View } from '@tarojs/components'
import { Component } from '@tarojs/taro'
import './index.scss'
import { getItemList } from '@/services/item'
import ready from '@/utils/ready'
import { connect } from '@tarojs/redux'

@connect(
  state => ({ ...state.user, ...state.city })
)
export default class Index extends Component {
  config = {
    navigationBarTitleText: '地产'
  }
  state = {
    PageList: [{}, {}, {}, {}, {}],
    filterOpt: {},
    pageIndex: 1,
    Org: null
  }
  componentWillMount () {
    ready.queue(async () => {
      this.setState({
        Org: this.props.userInfo.person.org || null
      })
      const { records: list } = await this.loadList(1, 10)
      this.setState({
        PageList: list
      })
    })
  }
  loadList (page = 0, pageSize = 10) {
    const { curCity } = this.props
    const { filterOpt } = this.state
    const currentPage = page || this.state.pageIndex
    const payload = Object.assign({ pageSize, pageNumber: currentPage, }, filterOpt)
    if (curCity.id) {
      payload.cityId = curCity.id
    }
    return getItemList(payload)
  }
  render () {
    const { PageList } = this.state
    return (
      <View className='Page'>

        {/* 顶部背景图 */}
        <View className='TopContainer'>
          {
            Org !== null ?
              <Image mode='widthFix' className='Bg' src={Org.thumb} />
              :
              <Image mode='widthFix' className='Bg' src={require('@/assets/img/topbg1.jpg')} />
          }
          <View className='Text'>
            <View>
              {/* <View><Text>“同理心”</Text>是雅居乐待人处事的第一原则，我们尊重每个人的需求和期望。</View>
              <View>不论是地产发展、物业服务，亦或其它产业，我们都本着将心比心的态度，务求从细微处了解每个人的需求，一点一滴改善生活的每 个细节。</View>
              <View>我们相信，这份坚持将为员工、客户和投资者带来永续的回报价值，成就更多自由自在、高枕无忧的快乐人生。</View> */}
              {
                Org !== null &&
                <RichText nodes={Org.orgDesc}></RichText>
              }
            </View>
          </View>
        </View>

        {/* 在售地产列表 */}
        <View className='DiChanList'>
          <View>
            <View className='flex-h Title'>
              <Text className='flex-item'>在售地产</Text>
              <Navigator className='More' url={'/pages/project/list/index'}>查看全部</Navigator>
              <Image mode='widthFix' className='Logo' src={require('@/assets/img/more.png')} />
            </View>
            {
              PageList.map((item, index) => (
                <Navigator key={`List-${index}`} className='flex-h ListItem' url={`/pages/project/detail/index?id=${item.buildingId}`}>
                  <View className='Img'>
                    <Image mode='aspectFill' className='centerLabel' src={item.buildingListImg !== null && item.buildingListImg.length ? item.buildingListImg[0].url : 'https://njcj.oss-cn-shanghai.aliyuncs.com/miniapp/images/default.jpg'} />
                  </View>
                  <View className='flex-item'>
                    {
                      Org !== null ?
                        <Image mode='widthFix' className='Logo' src={Org.waterMark} />
                        :
                        <Image mode='widthFix' className='Logo' src={require('@/assets/img/logo.png')} />
                    }
                    <View className='centerLabel'>
                      <View>
                        <Text>{item.buildingArea}</Text>
                        <Image mode='widthFix' src={require('@/assets/img/icon5.png')} />
                      </View>
                      <Text>{item.buildingName}</Text>
                    </View>
                  </View>
                </Navigator>
              ))
            }
          </View>
        </View>

      </View>
    )
  }
}
