import { View } from '@tarojs/components'
import { Component } from '@tarojs/taro'
import './index.scss'
import { GetShopList, GetShopTypeList, GetShopBanner } from '@/services/shop'
import ready from '@/utils/ready'
import ShopItem from './item'
import { connect } from '@tarojs/redux'
import ListView from '@/components/ListView'

@connect(
  state => ({ ...state.city })
)
export default class Index extends Component {
  config = {
    navigationBarTitleText: '乐客联盟',
    navigationStyle: 'custom'
  }
  state = {
    TestImg: 'https://timgsa.baidu.com/timg?image&quality=80&size=b9999_10000&sec=1604566584132&di=33926cb8407ae341fa1d8cc0d322d392&imgtype=0&src=http%3A%2F%2Fattach.bbs.miui.com%2Fforum%2F201305%2F30%2F220025pxfkhykvkgkvuktq.jpg',
    BannerData: [],
    isEmpty: false,
    SearchName: '',
    StoreList: [],
    NavList: [],
    PageNum: 1,
    hasMore: true,
    DataLock: false,
    CurrentTypeId: null,
    CityData: null
  }
  componentWillMount () {
    ready.queue(() => {
      const city = this.state.city || this.props.curCity
      this.setState({
        CityData: city
      }, () => {
        GetShopBanner({ pageNum: 1, pageSize: 10 }).then((res) => {
          this.setState({
            BannerData: res.records || []
          })
        })
        GetShopTypeList({ pageNum: 1, pageSize: 10 }).then((res) => {
          let Arr = res.records || []
          let aArr = []
          Arr.map((item, index) => {
            if ((Arr.length > 4 && index < 3 || Arr.length <= 4)) {
              aArr.push({ id: item.typeId, img: item.thumb, name: item.typeName })
            }
          })
          if (aArr.length === 3 && Arr.length > 4) {
            aArr.push({ id: 'all', img: require('@/assets/img/icon27.png'), name: '更多' })
          }
          this.setState({
            NavList: aArr,
            PageNum: 1,
            StoreList: [],
            SearchName: ''
          }, () => {
            this.ToGetPageList()
          })
        })
      })
    })
  }
  ToGetPageList () {
    if (!this.state.hasMore || this.DataLock) return
    this.DataLock = true
    GetShopList({ pageNum: this.state.PageNum, pageSize: 10, name: this.state.SearchName, sortField: 'sort_no' }).then((res) => {
      let Arr = res.records || []
      let aArr = []
      Arr.map((item) => {
        aArr.push({ ...item, badges: (item.badges || '').split(',') || [], lng: item.lngLat.split(',')[0], lat: item.lngLat.split(',')[1] })
      })
      this.setState({
        hasMore: res.total > this.state.StoreList.length + aArr.length,
        StoreList: this.state.StoreList.concat(aArr || [])
      }, () => {
        this.setState({
          isEmpty: !this.state.StoreList.length
        })
      })
      this.DataLock = false
    })
  }
  onPullDownRefresh = async (rest) => {
    this.setState({
      PageNum: 1,
      StoreList: [],
      hasMore: true,
      SearchName: ''
    }, () => {
      this.ToGetPageList()
      rest && rest()
    })
  }
  onScrollToLower = async (fn) => {
    this.setState({
      PageNum: this.state.PageNum + 1
    }, () => {
      this.ToGetPageList()
      fn && fn()
    })
  }
  GoBack () {
    Taro.navigateBack()
  }
  handleInput (e) {
    this.setState({ SearchName: e.detail.value })
  }
  handleSearch () {
    this.setState({
      PageNum: 1,
      StoreList: [],
      isEmpty: false,
      hasMore: true
    }, () => {
      Taro.navigateTo({ url: `/pages/league/list?type=all&key=${this.state.SearchName}` })
      // this.ToGetPageList()
    })
  }
  render () {
    const { NavList, StoreList, BannerData, CityData, hasMore, SearchName } = this.state
    return (
      <ListView
        className="wrap"
        needInit
        isEmpty={false}
        emptyText="暂无商家~"
        hasMore={hasMore}
        onPullDownRefresh={fn => this.onPullDownRefresh(fn)}
        onScrollToLower={fn => this.onScrollToLower(fn)}
      >
        <View className='Page'>

          <View className='DiyTop'>
            <Text>乐客联盟</Text>
            <Image mode='widthFix' src={require('@/assets/img/prev.png')} onClick={this.GoBack} />
          </View>

          <Image className="TopBg" src={require('@/assets/img/topbg.jpg')} mode='widthFix'></Image>

          {/* 搜索 */}
          <View className='SearchContainer'>
            <View>
              {
                SearchName === '' &&
                <View className='Placeholder'>
                  <Image src={require('@/assets/img/icon16.png')} mode='widthFix'></Image>
                  <Text>附近热搜：火锅</Text>
                </View>
              }
              <Input
                type="text"
                confirm-type="search"
                onInput={this.handleInput}
                onConfirm={this.handleSearch}
              />
            </View>
          </View>

          {/* banner区域 */}
          <View className='BannerContainer'>

            {/* banner */}
            <View className='Banner'>
              <View>
                <View>
                  {
                    BannerData.length &&
                    <Swiper className='Swiper' indicatorColor='rgba(0,0,0,0.4)' indicatorActiveColor='#fff' circular indicatorDots autoplay>
                      {
                        BannerData.map((item, index) => (
                          <SwiperItem key={`Swiper-${index}`}>
                            <Image mode='widthFix' className='centerLabel' src={item.thumb} />
                          </SwiperItem>
                        ))
                      }
                    </Swiper>
                  }
                </View>
              </View>
            </View>

            {/* nav */}
            <View className='Nav'>
              {
                NavList.map((item, index) => (
                  <Navigator className='Item' key={`Item-${index}`} url={`/pages/league/list?type=${item.id}&name=${item.name}`}>
                    <View>
                      <Image mode='heightFix' className='centerLabel' src={item.img} />
                    </View>
                    <Text>{item.name}</Text>
                  </Navigator>
                ))
              }
            </View>

          </View>

          {/* 乐客商家 */}
          <View className='LeKeStore'>
            {
              StoreList.map((item, index) => (
                <View>
                  <View className='Line'></View>
                  <ShopItem item={item} lat={CityData.lat} lng={CityData.lng} key={`Store-${index}`}></ShopItem>
                </View>
              ))
            }
          </View>

        </View>
      </ListView>
    )
  }
}
