import Taro, { Component } from '@tarojs/taro';
import './index.scss'
import { ROLE_CODE } from '@/constants/user'
import { queryUserInfo, doUserSignin } from '@/services/user'
import { GetUserLevel } from '@/services/person'
import { connect } from '@tarojs/redux'
import Notice from '@/components/Notice'
import { getCodeMessage, putRegisterConsultant } from '@/services/getCode'
import * as actions from '@/actions/user'
import Authorize from '@/components/authorize'
import { transferImage } from '@/utils/tools'
import { savePoint, } from '@/services/common'
import { menus } from './menus'
import login from '@/utils/login'
export const version = Version
import { rule as ruleToast } from '@/utils/ruleToast'
import { Loading } from '@/components/Loading'
import ready from '@/utils/ready'

const DRIFT = ROLE_CODE['DRIFT']
const CUSTOMER = ROLE_CODE['CUSTOMER']
const CONSULTANT = ROLE_CODE['CONSULTANT']
const ESTATE_AGENT = ROLE_CODE['ESTATE_AGENT']
const CHANNEL_AGENT = ROLE_CODE['CHANNEL_AGENT']

@connect(({ user, city }) => ({ user, city }), { ...actions })

export default class Person extends Component {
  config = {
    navigationBarTitleText: '我的',
    navigationStyle: 'custom'
  }

  state = {
    isLogin: false,
    users: {},
    isAgent: false,//经纪人
    consultant: false,//置业顾问
    tourist: false,//普通用户,
    menus: [],
    roleName: '普通用户',
    pageVisible: false,
    loading: true,
    UserLevelIcon: null,
    Org: null,
    UserMenus: [
      [
        {
          name: '我的主页',
          url: ({ id }) => `/pages/card/index?id=${id}`,
          icon: require('@/assets/img/wodeicon1.png'),
          extends: undefined,
          userTypes: [CONSULTANT],
        },
        {
          name: '我的分享',
          url: `/pages/person/myShare/index`,
          icon: require('@/assets/img/wodeicon2.png'),
          extends: undefined,
          userTypes: [CUSTOMER, CONSULTANT, ESTATE_AGENT, CHANNEL_AGENT],
        }
      ],
      [
        {
          name: '我的活动',
          url: `/pages/activity/myActivity?from=mine`,
          icon: require('@/assets/img/wodeicon3.png'),
          extends: undefined,
          userTypes: [CUSTOMER, CONSULTANT, ESTATE_AGENT, CHANNEL_AGENT],
        },
        {
          name: '我的拼团',
          url: `/pages/activity/assemblePage`,
          icon: require('@/assets/img/wodeicon4.png'),
          extends: undefined,
          userTypes: [CUSTOMER, CONSULTANT, ESTATE_AGENT, CHANNEL_AGENT],
        },
        {
          name: '我的助力',
          url: `/pages/activity/assistancePage`,
          icon: require('@/assets/img/wodeicon5.png'),
          extends: undefined,
          userTypes: [CUSTOMER, CONSULTANT, ESTATE_AGENT, CHANNEL_AGENT],
        },
        {
          name: '我的抽奖',
          url: null,
          icon: require('@/assets/img/wodeicon6.png'),
          extends: undefined,
          userTypes: [CUSTOMER, CONSULTANT, ESTATE_AGENT, CHANNEL_AGENT],
        },
        {
          name: '我的集卡',
          url: null,
          icon: require('@/assets/img/wodeicon7.png'),
          extends: undefined,
          userTypes: [CUSTOMER, CONSULTANT, ESTATE_AGENT, CHANNEL_AGENT],
        },
        {
          name: '我的秒杀',
          url: null,
          icon: require('@/assets/img/wodeicon8.png'),
          extends: undefined,
          userTypes: [CUSTOMER, CONSULTANT, ESTATE_AGENT, CHANNEL_AGENT],
        }
      ],
      [
        {
          name: '我的收藏',
          url: `/pages/person/favorite/index`,
          icon: require('@/assets/img/wodeicon9.png'),
          extends: undefined,
          userTypes: [CUSTOMER, CONSULTANT, ESTATE_AGENT, CHANNEL_AGENT],
        },
        {
          name: '兑换记录',
          url: `/useless/pages/shop/record/index`,
          icon: require('@/assets/img/wodeicon10.png'),
          extends: undefined,
          userTypes: [CUSTOMER, CONSULTANT, ESTATE_AGENT, CHANNEL_AGENT],
        }
      ]
    ]
  }
  componentWillMount () {
    ready.queue(() => {
      console.log(this.props, `--------------------------------------------1111111111111111111111111`)
      this.setState({
        Org: this.props.user.userInfo.person.org || null
      })
    })
  }

  componentDidShow () {
    Taro.showLoading()
    this.loadUserInfo()
    Taro.hideLoading()
  }

  loadUserInfo () {
    queryUserInfo().then(users => {
      const [roleSetting, roleName] = this.getRoleName(users.personType)
      console.log(users, `---------------------------------------------`)
      this.setState({
        users,
        phone: users.phone,
        loading: false,
        pageVisible: !users.phone && !users.tel,
        menus: this.state.UserMenus.map(group => group.filter(x => x.userTypes.indexOf(users.personType) > -1)),
        roleName,
        ...roleSetting,
      })
      GetUserLevel({ pageNum: 1, pageSize: 10000 }).then((res) => {
        res.records.map((item) => {
          if (users.points - 0 >= item.pointRule.split(',')[0] && users.points - 0 <= item.pointRule.split(',')[1]) {
            this.setState({
              UserLevelIcon: item.levelIcon
            })
          }
        })
      })
    })
  }

  doSign () {
    const { users: { id, havaSigned } } = this.state
    if (havaSigned) {
      return
    }

    doUserSignin({ id }).then(res => {
      ruleToast('checkin')
      savePoint({
        event: 'signin',
        eventType: 'center',
        propertyName: '签到',
        data: '{}'
      }).then(res => {
        console.log('签到')
      })
      // this.setState({
      //   user: {
      //     points: res.points
      //   }
      // })

      setTimeout(() => {
        this.loadUserInfo()
      }, 1000)

      // App.zhuge.track('签到成功')
    })
  }

  toHomePage () {
    Taro.switchTab({
      url: '/pages/project/index'
    })
  }

  toShopPage () {
    Taro.switchTab({
      url: '/pages/shop/index'
    })
  }
  redirectTo = (url) => {
    if (url) {
      if (typeof url === 'function') {
        Taro.navigateTo({ url: url(this.state.users) })
      } else {
        Taro.navigateTo({ url })
      }
    }
    else {
      putRegisterConsultant().then(res => {
        Taro.showToast({
          title: "匹配成功",
          icon: "none",
          duration: 3000
        })
        Taro.setStorageSync('userId', res.userId)
        const payload = {
          path: '',
          scene: ''
        }

        login(payload, res => {
          this.loadUserInfo()
        })


        // this.setState({
        //   consultant:true,
        //   user:{
        //     personType:'CONSULTANT'
        //   }
        // },this.loadUserInfo())

        // if (res) {
        // Taro.showToast({
        //   title: "匹配成功，请退出小程序重新登录即可",
        //   icon: "none",
        //   duration: 3000
        // })
        // } else {
        //   Taro.showToast({
        //     title: "匹配失败，请联系相关管理人员",
        //     icon: "none",
        //     duration: 3000
        //   })
        // }
      }).catch(err => {
        console.error(err)
        Taro.showToast({
          title: "匹配失败，请联系相关管理人员",
          icon: "none",
          duration: 3000
        })
      })
    }

  }

  getRoleName (type) {
    switch (type) {
      case ROLE_CODE['CONSULTANT']:
        return [{ consultant: true }, '置业顾问']
      case ROLE_CODE['ESTATE_AGENT']:
        return [{ isAgent: true }, '专业经纪人']
      case ROLE_CODE['CHANNEL_AGENT']:
        return [{ isAgent: true }, '专业经纪人']
      default:
        return [{ tourist: true }, '普通用户']
    }
  }

  // getRoleName(type) {
  //   switch (type) {
  //     case ROLE_CODE['CONSULTANT']:
  //       return [{ consultant: true }, '置业顾问']
  //     case ROLE_CODE['ESTATE_AGENT']:
  //       return [{ isAgent: true }, '普通用户']
  //     case ROLE_CODE['CHANNEL_AGENT']:
  //       return [{ isAgent: true }, '专业经纪人']
  //     default:
  //       return [{ tourist: true }, '普通用户']
  //   }
  // }

  goShop () {
    Taro.switchTab({
      url: `/pages/shop/index`
    })
  }
  handleMore () {
    Taro.showModal({
      title: '温馨提示',
      content: '敬请期待'
    })
  }

  ToastMsg (msg) {
    Taro.showToast({
      title: msg,
      icon: 'none'
    })
  }

  goPersonDetail () {

    const { users: { personType } } = this.state

    // if (personType == ROLE_CODE['CHANNEL_AGENT'] || personType == ROLE_CODE['ESTATE_AGENT']) {
    Taro.navigateTo({
      url: '/pages/person/personDetail/index'
    })
    // }

  }

  renderLogin () {
    const achieveParams = {
      buildingId: '',
      targetName: '我的地盘',
      targetType: 'other',
      targetId: '',
    }
    return <Authorize achieveParams={achieveParams}></Authorize>
  }

  renderDetail () {
    const { users, menus, roleName, UserLevelIcon, Org } = this.state
    const { user: { userInfo: { person: { avatarurl, org: { waterMark } = {} }, miniApp: { name } } } } = this.props

    // const showQRCode = user.personType === ROLE_CODE['CONSULTANT'] || ROLE_CODE['ESTATE_AGENT'] || ROLE_CODE['CHANNEL_AGENT']
    // const isConsultant = user.personType == ROLE_CODE['CONSULTANT']
    // const isConsultant = user.personType
    return (
      <View className="person">
        <Notice></Notice>
        <View className="info">
          <Image className="bg" src={require('@/assets/img/topbg.jpg')} mode='widthFix'></Image>
          {
            Org !== null &&
            <Image className="WaterMark" src={Org.waterMark} mode='widthFix'></Image>
          }

          <View className="content">
            <View className="info-block">
              <View className="avatar" onClick={this.goPersonDetail}>
                <Image className="info__headimg" src={avatarurl} />
                {/* <Image className="info__headimg" src={users.avatar} /> */}
                {/* <View className="info-intro">{roleName}</View> */}
              </View>

              <View className="info-text" onClick={this.goPersonDetail}>
                <View className="UserName">
                  <Text>{users.name ? users.name : users.nickname}</Text>
                  {
                    UserLevelIcon !== null &&
                    <Image src={UserLevelIcon} mode='widthFix'></Image>
                  }
                </View>
                <View className="info-text__intro" style='color: #666;'>积分 {users.points || 0}</View>
              </View>
              {
                users.personType == 'Realty Consultant' && (
                  <Navigator url={`/pages/person/spread/index`} className="tuiguang">

                    <Image style="width:40px;height:36px" src={require('@/assets/mine/tuiguangma.png')} ></Image>
                    <View className="info-text__intro" style="margin:4px 0 0 4px">推广码</View>
                  </Navigator>
                )
              }
            </View>
            {/* <View
              className={`sign__btn ${user.havaSigned && 'signed'}`}
              onClick={this.doSign}>{user.havaSigned ? '已打卡' : '打卡'}
            </View> */}

          </View>
          <View className='qiandao-con'>
            <Text className='qiandao-text'>签到得积分，积分兑好礼，马上去签到吧！</Text>
            <View className={users.havaSigned ? 'reday-qiandao-btn' : 'qiandao-btn'} onClick={this.doSign}>{users.havaSigned ? '已签到' : '签到'}</View>
            {/* {
              user.havaSigned ?
                (<View className='reday-qiandao-btn' onClick={this.doSign}> 已签到</View>) :
                (<View className='qiandao-btn' onClick={this.doSign}>签到</View>)
            } */}
            {/* <Text className='integral-cont_btn' onClick={this.goShop}>去兑换</Text> */}

          </View>
        </View>
        <View>
          <View className='line'></View>
          {
            menus.map((group, ginx) => (
              <Block key={`grp-${ginx}`}>
                {
                  group.map((menu, inx) => (
                    <View onClick={() => { menu.url === null ? this.ToastMsg('敬请期待') : this.redirectTo(menu.url) }} style={{ color: menu.style }} className="menu-item-con" key={`menu-${inx}`}>
                      <Image className="left-icon" src={menu.icon} ></Image>
                      <View className="menu-maintext">
                        <Text className="menu-name" style={menu.style}>{menu.name}</Text>
                        <Text className="right-icon"></Text>
                      </View>
                    </View>
                  ))
                }
                <View className='line'></View>
              </Block>
            ))
          }
        </View>
        {/* <View style="text-align:center;color:#ccc;line-height:1.5;font-size:22rpx;padding:20rpx 0 4rpx 0 ">
          <View style="font-size:26rpx;color:#999;"> {version}</View>
          <View > 南京云致提供技术支持 </View>
          <View >{name}提供运营方案 </View>
        </View> */}
      </View>
    );
  }

  render () {
    // const { phone, tel } = this.state.users
    const { loading, pageVisible } = this.state
    if (loading) {
      return <View style="margin: 80px auto;"><Loading color="#BB9C79" size={100} /></View>
    }
    return (
      <View className='wrap'>
        {/* {(phone || tel) && this.renderDetail()} */}
        {pageVisible ? this.renderLogin() : this.renderDetail()}
      </View>
    )
  }
}
